"use client";

import { Button } from "@/components/ui/button";
import {
	Dialog,
	DialogClose,
	DialogContent,
	DialogDescription,
	DialogFooter,
	DialogHeader,
	DialogTitle,
	DialogTrigger,
} from "@/components/ui/dialog";
import { useEffect, useMemo, useState, useTransition } from "react";

// Import FormBuilder components
import FormBuilder from "@/components/FormBuilder/form-builder";
import InputField from "@/components/FormBuilder/FormFields/input-field";
import useFormBuilder from "@/components/FormBuilder/hooks/use-form-builder";
import prepareFields from "@/components/FormBuilder/utils/prepare-fields";
import Yup from "@/components/FormBuilder/utils/yup";
import PhoneInput from "@/components/ui/phone-input";
import { Loader2 } from "lucide-react";
import { toast } from "sonner";

interface RecipientDialogProps {
	onSave?: (data: any) => void;
	initialData?: {
		first_name?: string;
		middle_name?: string;
		last_name?: string;
		phone?: string;
		email?: string;
	};
	triggerButton?: React.ReactNode;
	disabledFields?: string[];
	isOpen?: boolean;
	onOpenChange?: (open: boolean) => void;
	title: string;
}

export default function RecipientDialog({ onSave, initialData, triggerButton, disabledFields = [], isOpen, onOpenChange, title }: RecipientDialogProps) {
	const [isPending, startTransition] = useTransition();
	const [internalIsOpen, setInternalIsOpen] = useState(false);

	// Use the external isOpen state if provided, otherwise use internal state
	const isDialogOpen = isOpen !== undefined ? isOpen : internalIsOpen;
	const setIsDialogOpen = onOpenChange || setInternalIsOpen;

	// Reset form when dialog is closed or initialData changes
	useEffect(() => {
		// Reset form to initial values when dialog is opened or initialData changes
		RecipientFormHooks.reset({
			first_name: initialData?.first_name || "",
			middle_name: initialData?.middle_name || "",
			last_name: initialData?.last_name || "",
			phone: initialData?.phone || "",
			email: initialData?.email || "",
		});
	}, [initialData, isDialogOpen]);

	// Define fields for the recipient dialog using useFormBuilder
	const recipientFields = useMemo(
		() =>
			prepareFields({
				first_name: {
					yup: Yup.string().required("الاسم الأول مطلوب"),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: "الاسم الأول",
						placeholder: "الاسم الأول",
						containerClassName: "col-span-12",
						inputProps: {
							disabled: disabledFields.includes("first_name"),
						}
					}),
				},
				middle_name: {
					yup: Yup.string().nullable(),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: "الاسم الأوسط",
						placeholder: "الاسم الأوسط",
						containerClassName: "col-span-12",
						inputProps: {
							disabled: disabledFields.includes("middle_name"),
						}
					}),
				},
				last_name: {
					yup: Yup.string().required("الاسم الأخير مطلوب"),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: "الاسم الأخير",
						placeholder: "الاسم الأخير",
						containerClassName: "col-span-12",
						inputProps: {
							disabled: disabledFields.includes("last_name"),
						}
					}),
				},
				phone: {
					yup: Yup.string().required("رقم الهاتف مطلوب"),
					type: "input",
					component: (props: any) => (
						<div className="p-2 col-span-12">
							<label htmlFor="phone" className="mb-1 block text-base font-medium text-gray-700">
								رقم الهاتف
							</label>
							<div className="rounded-md border border-gray-300 bg-white h-11 mt-3 p-2">
								<PhoneInput
									{...props}
									value={initialData?.phone ? initialData?.phone?.slice(3) : props.value}
									onChange={(value: string | number) => {
										if (props.onChange) {
											props.onChange(value);
										}
									}}
									labelclassName="text-right"
									className="h-11 -mt-2"
									disabled={props.inputProps.disabled}
								/>
							</div>
						</div>
					),
					componentProps: ({ }) => ({
						type: "text",
						containerClassName: "col-span-12",
						dir: "ltr",
						inputProps: {
							disabled: disabledFields.includes("phone"),
						},
						onChange: (value: string | number) => {
							RecipientFormHooks.setValue("phone", `966${value}`);
						}
					}),
				},
				email: {
					yup: Yup.string().email("البريد الإلكتروني غير صالح").required("البريد الإلكتروني مطلوب"),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "email",
						label: "البريد الإلكتروني",
						placeholder: "البريد الإلكتروني",
						containerClassName: "col-span-12",
						inputProps: {
							disabled: disabledFields.includes("email"),
						}
					}),
				},
			}),
		[disabledFields]
	);

	// Initialize form hooks for the recipient dialog
	const RecipientFormHooks = useFormBuilder(recipientFields as any, {
		defaultValues: {
			first_name: initialData?.first_name || "",
			middle_name: initialData?.middle_name || "",
			last_name: initialData?.last_name || "",
			phone: initialData?.phone || "",
			email: initialData?.email || "",
		},
	});

	// Handle form submission for the recipient dialog
	async function onSubmitRecipientInfo(data: any) {
		console.log("onSubmitRecipientInfo function called with data:", data);
		try {
			startTransition(async () => {
				console.log("Inside startTransition, saving recipient data:", data);

				// Call the onSave callback if provided
				if (onSave) {
					console.log("Calling onSave callback with data:", data);
					onSave(data);
				}

				// Show success message
				toast.success("تم حفظ معلومات المستلم بنجاح", {
					style: {
						backgroundColor: "green",
						color: "white",
					},
				});

				// Close the dialog after saving
				setIsDialogOpen(false);
			});
		} catch (error) {
			console.error("Form submission error:", error);
			toast.error("حدث خطأ أثناء حفظ المعلومات");
		}
	}

	return (
		<Dialog open={isDialogOpen} onOpenChange={setIsDialogOpen}>
			{triggerButton && (
				<DialogTrigger asChild>
					{triggerButton}
				</DialogTrigger>
			)}
			<DialogContent className="sm:max-w-[600px]" dir="rtl">
				<DialogHeader>
					<DialogTitle>{title}</DialogTitle>
					<DialogDescription>يرجى تأكد من صحة معلوماتك</DialogDescription>
				</DialogHeader>
				<form
					onSubmit={(e) => {
						console.log("Form submit event triggered");
						e.preventDefault(); // Prevent default form submission

						// Log form values before validation
						console.log("Form values before validation:", RecipientFormHooks.getValues());

						// Check if form is valid
						RecipientFormHooks.trigger().then(isValid => {


							// Check each field individually
							const fields = ["first_name", "middle_name", "last_name", "phone", "email"];
							fields.forEach(field => {
								RecipientFormHooks.trigger(field as any).then(fieldIsValid => {
									console.log(`Field ${field} validation:`, {
										error: RecipientFormHooks.formState.errors[field as keyof typeof RecipientFormHooks.formState.errors]
									});
								});
							});
							console.log(RecipientFormHooks.formState.errors["phone"]);
							if (isValid) {
								const formData = RecipientFormHooks.getValues();
								console.log("Form is valid, calling onSubmitRecipientInfo with:", formData);
								onSubmitRecipientInfo(formData);
							} else {
								console.log("Form validation errors:", RecipientFormHooks.formState.errors);
								// Show validation errors to the user
								toast.error("يرجى التحقق من صحة جميع الحقول المطلوبة");
							}
						});
					}}
				>
					<div className="grid gap-4 py-4">
						<FormBuilder fields={recipientFields} FormHooks={RecipientFormHooks} />
					</div>
					<DialogFooter className="flex justify-end gap-2">
						<Button
							type="submit"
							disabled={isPending}
							onClick={() => console.log("Submit button clicked")}
						>
							{isPending ? <Loader2 className="mx-auto w-4 h-4 animate-spin" /> : "حفظ"}
						</Button>
						<DialogClose asChild><Button type="button" variant="outline">إلغاء</Button></DialogClose>
					</DialogFooter>
				</form>
			</DialogContent>
		</Dialog>
	);
} 